@@ -17,7 +17,7 @@ address
  5,000,001 - 30,000,000  working area 
 30,000,001 - 32,000,000  variant area
 */
-#define VERSION     4.76
+#define VERSION     4.78
 //#define CELLSIZE    30000000  // if raspberry PI set smaller size.
 #define HEAPSIZE     5000000
 #define FREESIZE         500
@@ -38,7 +38,7 @@ address
 #define FUNCTION_NUMBER 22
 #define BUILTIN_NUMBER 220
 #define COMPILED_NUMBER 10
-#define EXTENDED_NUMBER 53
+#define EXTENDED_NUMBER 60
 #define NIL         0
 #define YES         2
 #define NO          4
@@ -187,7 +187,7 @@ enum { LIST3_IDX, ERRORCOMP_IDX, WLISTCONS_IDX,UNIFY_IDX, UNIFY_PAIR_IDX,
        UNIFY_INT_IDX, UNIFY_FLT_IDX, UNIFY_LONG_IDX, UNIFY_BIG_IDX, UNIFY_STR_IDX,
        UNIFY_VAR_IDX, UNIFY_ATOM_IDX, EXEC_ALL_IDX, PROVE_ALL_IDX, WCONS_IDX,
        WLIST2_IDX, ADDTAIL_BODY_IDX, PLUS_IDX, MINUS_IDX, MULT_IDX, DIVIDE_IDX, REMAINDER_IDX,
-       QUOTIENT_IDX,  MOD_IDX, EXPT_IDX, DIV_IDX,
+       QUOTIENT_IDX,  MOD_IDX, EXPT_IDX, DIV_IDX, XOR_IDX,
        LEFTSHIFT_IDX, RIGHTSHIFT_IDX, LOGICALAND_IDX, LOGICALOR_IDX, ROUND_IDX,
        CALL_IDX,
        NUM_FN3S,
@@ -328,7 +328,9 @@ enum Type {
 //debugger
 #define OFF     0
 #define ON      1
-    
+
+
+
 /* distributed parallel */
 #define PORT 5000 
 extern pthread_mutex_t mutex2;
@@ -913,6 +915,13 @@ int b_n_get_dynamic(int arglist, int rest, int th);
 int b_n_get_execute(int arglist, int rest, int th);
 int b_n_greater(int arglist, int rest, int th);
 int b_ground(int arglist, int rest, int th);
+int b_gr_open(int arglist, int rest, int th);
+int b_gr_close(int arglist, int rest, int th);
+int b_gr_cls(int arglist, int rest, int th);
+int b_gr_pset(int arglist, int rest, int th);
+int b_gr_circle(int arglist, int rest, int th);
+int b_gr_rect(int arglist, int rest, int th);
+int b_gr_line(int arglist, int rest, int th);
 int b_halt(int arglist, int rest, int th);
 int b_n_has_cut(int arglist, int rest, int th);
 int b_heapdump(int arglist, int rest, int th);
@@ -1149,6 +1158,7 @@ int f_mod(int x, int y, int th);
 int f_mult(int x, int y, int th);
 int f_plus(int x, int y, int th);
 int f_rightshift(int x, int y, int th);
+int f_xor(int x, int y, int th);
 int f_round(int x, int y, int th);
 int f_sqrt(int x, int th);
 int f_sin(int x, int th);
